@@ -54,9 +54,8 @@ te_renyi <- function(x,
         nboot, mult_s(nboot)
       ))
     }
-    seeds <- sample(.Machine$integer.max, nboot)
-    boot <- future.apply::future_sapply(seeds, function(seed) {
-      set.seed(seed)
+
+    boot <- future.apply::future_sapply(seq_len(nboot), function(i) {
       bootstrap_renyi(
         x = x,
         lx = lx,
@@ -65,7 +64,7 @@ te_renyi <- function(x,
         q = q,
         burn = burn
       )
-    })
+    }, future.seed = TRUE)
   } else {
     boot <- NA
   }
